[−][src]Struct lorawan_encoding::maccommands::DutyCycleReqPayload
DutyCycleReqPayload represents the DutyCycleReq LoRaWAN MACCommand.
Implementations
impl<'a> DutyCycleReqPayload<'a>[src]
pub fn new<'b>(data: &'a [u8]) -> Result<DutyCycleReqPayload<'a>, &'b str>[src]
Creates a new instance of the mac command if there is enought data.
pub fn new_as_mac_cmd<'b>(
data: &'a [u8]
) -> Result<(MacCommand<'a>, usize), &'b str>[src]
data: &'a [u8]
) -> Result<(MacCommand<'a>, usize), &'b str>
pub const fn cid() -> u8[src]
Command identifier.
pub const fn uplink() -> bool[src]
Sent by end device or sent by network server.
pub const fn len() -> usize[src]
length of the payload of the mac command.
impl<'a> DutyCycleReqPayload<'a>[src]
pub fn max_duty_cycle_raw(&self) -> u8[src]
Integer value of the max duty cycle field.
pub fn max_duty_cycle(&self) -> f32[src]
Value of the max duty cycle field as portion of time (ex: 0.5).